====================
Core Building Blocks
====================

The Jupyter architecture relies on these projects' specifications and
implementation.

.. glossary::

    `jupyter_client <https://jupyter-client.readthedocs.io/en/latest/>`__
        The specification of the Jupyter message protocol and a client library
        in Python.
        `Documentation <https://jupyter-client.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyter/jupyter_client>`__

    `jupyter_core <https://jupyter-core.readthedocs.io/en/latest/>`__
        Core functionality and miscellaneous utilities.
        `Documentation <https://jupyter-core.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyter/jupyter_core>`__
